==> xkeycaps_2.29-3.tar.gz: xkeycaps-2.29/kbds/hp4032x-geom.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the physical layout of the HP 4032 (aka Aptrex) X terminal
 * keyboard. This layout mimics the Sun type 5 "PC" version. You could probably
 * use that file (sun5-geom.h) with appropriate definitions.
 * By Mark Borges <mdb@cdc.noaa.gov>
 *
 * This file describes the physical layout of the Sun type 5 keyboards.  
 * By Carl Witty <cwitty@ai.mit.edu>, Sylvain Meunier <meunier@inf.enst.fr>,
 * and jwz.
 *
 * The "PC" version differs from the regular type 5 keyboard in that the top
 * row of the main block ends in a wide BS key instead of "|\" and "~`", and 
 * the first key on the bottom row (Control here, Caps on the other one) is
 * wider.
 */

static struct key_geometry hp4032x_geom_row0 [] = {
 {14, 7}, {4, 0},
 {7, 7}, {7, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {3, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}
};

static struct key_geometry hp4032x_geom_row1 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {14, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}
};

static struct key_geometry hp4032x_geom_row2 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {10, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {11, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 14}
};

static struct key_geometry hp4032x_geom_row3 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {13, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {15, 7}, {29, 0},
 {7, 7}, {7, 7}, {7, 7}
};

static struct key_geometry hp4032x_geom_row4 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {16, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {19, 7}, {11, 0},
 {7, 7}, {11, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 14}
};

static struct key_geometry hp4032x_geom_row5 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {13, 7}, {7, 7}, {7, 7}, {57, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {14, 7}, {7, 7}
};

static struct keyboard_row_geometry hp4032x_geom_rows [] = {
  ROW (hp4032x_geom_row0, 7),
  EMPTYROW (7),
  ROW (hp4032x_geom_row1, 7),
  ROW (hp4032x_geom_row2, 7),
  ROW (hp4032x_geom_row3, 7),
  ROW (hp4032x_geom_row4, 7),
  ROW (hp4032x_geom_row5, 7),
};

static struct keyboard_geometry hp4032x_geom = {
  sizeof (hp4032x_geom_rows) / sizeof (struct keyboard_row_geometry),
  hp4032x_geom_rows, 6, 3, 3
};

==> xkeycaps_2.42.orig.tar.gz: xkeycaps-2.42/kbds/hp4032x-geom.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the physical layout of the HP 4032 (aka Aptrex) X terminal
 * keyboard. This layout mimics the Sun type 5 "PC" version. You could probably
 * use that file (sun5-geom.h) with appropriate definitions.
 * By Mark Borges <mdb@cdc.noaa.gov>
 *
 * This file describes the physical layout of the Sun type 5 keyboards.  
 * By Carl Witty <cwitty@ai.mit.edu>, Sylvain Meunier <meunier@inf.enst.fr>,
 * and jwz.
 *
 * The "PC" version differs from the regular type 5 keyboard in that the top
 * row of the main block ends in a wide BS key instead of "|\" and "~`", and 
 * the first key on the bottom row (Control here, Caps on the other one) is
 * wider.
 */

static const struct key_geometry hp4032x_geom_row0 [] = {
 {14, 7}, {4, 0},
 {7, 7}, {7, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {3, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}
};

static const struct key_geometry hp4032x_geom_row1 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {14, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}
};

static const struct key_geometry hp4032x_geom_row2 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {10, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {7, 7}, {11, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 14}
};

static const struct key_geometry hp4032x_geom_row3 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {13, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {7, 7}, {15, 7}, {29, 0},
 {7, 7}, {7, 7}, {7, 7}
};

static const struct key_geometry hp4032x_geom_row4 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {16, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7}, {7, 7},
 {7, 7}, {7, 7}, {19, 7}, {11, 0},
 {7, 7}, {11, 0},
 {7, 7}, {7, 7}, {7, 7}, {7, 14}
};

static const struct key_geometry hp4032x_geom_row5 [] = {
 {7, 7}, {7, 7}, {4, 0},
 {13, 7}, {7, 7}, {7, 7}, {57, 7}, {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {7, 7}, {7, 7}, {7, 7}, {4, 0},
 {14, 7}, {7, 7}
};

static const struct keyboard_row_geometry hp4032x_geom_rows [] = {
  ROW (hp4032x_geom_row0, 7),
  EMPTYROW (7),
  ROW (hp4032x_geom_row1, 7),
  ROW (hp4032x_geom_row2, 7),
  ROW (hp4032x_geom_row3, 7),
  ROW (hp4032x_geom_row4, 7),
  ROW (hp4032x_geom_row5, 7),
};

static const struct keyboard_geometry hp4032x_geom = {
  sizeof (hp4032x_geom_rows) / sizeof (struct keyboard_row_geometry),
  hp4032x_geom_rows, 6, 3, 3
};
